@@ -55,6 +55,8 @@ class Salade(object):
         def link_repl(link):
             if link.startswith('http://') or link.startswith('https://'):
                 return link
+            elif link.startswith('/_salade/'):
+                return self.config['script_name'] + link
             elif link.startswith('/'):
                 return join(host_url, link.lstrip('/'))
             elif link.startswith("#"):
@@ -79,6 +81,8 @@ class Salade(object):
         if url.startswith('/'):
             req.path_info = url
             resp = req.get_response(self.config['application'])
+        else:
+            resp = Response()
         if resp.content_type.startswith('text/html') and resp.status.startswith('200'):
             return resp
         return None
