@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
 import urlparse
-from utils import Request
+from utils import Request, Response
 from lxml.html import tostring
 from pyquery import PyQuery
 from salade import Salade
@@ -41,6 +41,17 @@ class Saladier(object):
         self.salade = klass
         self.config = config
 
+    def get(self, url):
+        """get an html page from the app or an url"""
+        if url.startswith('/'):
+            req = Request.blank(url)
+            resp = req.get_response(self.application)
+        else:
+            resp = Response()
+        if resp.content_type.startswith('text/html') and resp.status.startswith('200'):
+            return resp
+        return None
+
     def __call__(self, environ, start_response):
         req = Request(environ)
         if req.path_info.startswith('/_salade/'):
@@ -57,14 +68,14 @@ class Saladier(object):
                 host, port = host.split(':')
             else:
                 port = scheme == 'https' and '443' or '80'
-        elif 'X-Forwarded-Host' in req.environ:
-            host = req.environ.pop('X-Forwarded-Host').split(':')[0]
-            if 'X-Forwarded-Proto' in req.environ:
-                req.scheme = req.environ.pop('X-Forwarded-Proto')
-            if 'X-Forwarded-Scheme' in req.environ:
-                req.scheme = req.environ.pop('X-Forwarded-Scheme')
-            if 'X-Forwarded-Port' in req.environ:
-                port = req.environ.pop('X-Forwarded-Port')
+        elif 'HTTP_X_FORWARDED_HOST' in req.environ:
+            host = req.environ.pop('HTTP_X_FORWARDED_HOST').split(':')[0]
+            if 'HTTP_X_FORWARDED_PROTO' in req.environ:
+                req.scheme = req.environ.pop('HTTP_X_FORWARDED_PROTO')
+            if 'HTTP_X_FORWARDED_SCHEME' in req.environ:
+                req.scheme = req.environ.pop('HTTP_X_FORWARDED_SCHEME')
+            if 'HTTP_X_FORWARDED_PORT' in req.environ:
+                port = req.environ.pop('HTTP_X_FORWARDED_PORT')
             else:
                 port = req.scheme == 'https' and '443' or '80'
         else:
@@ -82,10 +93,15 @@ class Saladier(object):
         if port == '443':
             req.scheme = 'https'
 
+        if 'HTTP_X_FORWARDED_PATH' in req.environ:
+            req.script_name = req.environ['HTTP_X_FORWARDED_PATH']
+
+        config = self.config.copy()
+        config.update(script_name=req.script_name)
         resp = req.get_response(self.application)
-        if resp.content_type and resp.content_type.startswith('text/html'):
+        status = resp.status[0]
+        if resp.content_type and resp.content_type.startswith('text/html') and status in '245':
             theme = PyQuery(self.theme, parser='html')
-            config = self.config.copy()
             config.update(application=self.application)
             body = self.salade(resp.doc, theme, req, resp, **config)()
             if isinstance(body, str):
